@@ -238,6 +238,26 @@ macro_rules! impl_mat4_methods {
             Self($inner::from_scale(scale.0))
         }
 
+        /// Creates a 4x4 matrix from the first 16 values in `slice`.
+        ///
+        /// # Panics
+        ///
+        /// Panics if `slice` is less than 16 elements long.
+        #[inline(always)]
+        pub fn from_cols_slice(slice: &[$t]) -> Self {
+            Self(Matrix4x4::from_cols_slice(slice))
+        }
+
+        /// Writes the columns of `self` to the first 16 elements in `slice`.
+        ///
+        /// # Panics
+        ///
+        /// Panics if `slice` is less than 16 elements long.
+        #[inline(always)]
+        pub fn write_cols_to_slice(self, slice: &mut [$t]) {
+            Matrix4x4::write_cols_to_slice(&self.0, slice)
+        }
+
         /// Returns the matrix column for the given `index`.
         ///
         /// # Panics
@@ -310,6 +330,7 @@ macro_rules! impl_mat4_methods {
         }
 
         /// Returns the transpose of `self`.
+        #[must_use]
         #[inline(always)]
         pub fn transpose(&self) -> Self {
             Self(self.0.transpose())
@@ -324,6 +345,7 @@ macro_rules! impl_mat4_methods {
         /// Returns the inverse of `self`.
         ///
         /// If the matrix is not invertible the returned matrix will be invalid.
+        #[must_use]
         #[inline(always)]
         pub fn inverse(&self) -> Self {
             Self(self.0.inverse())
@@ -604,7 +626,7 @@ macro_rules! impl_mat4_traits {
         impl Add<$mat4> for $mat4 {
             type Output = Self;
             #[inline(always)]
-            fn add(self, other: Self) -> Self {
+            fn add(self, other: Self) -> Self::Output {
                 self.add_mat4(&other)
             }
         }
@@ -612,7 +634,7 @@ macro_rules! impl_mat4_traits {
         impl Sub<$mat4> for $mat4 {
             type Output = Self;
             #[inline(always)]
-            fn sub(self, other: Self) -> Self {
+            fn sub(self, other: Self) -> Self::Output {
                 self.sub_mat4(&other)
             }
         }
@@ -620,7 +642,7 @@ macro_rules! impl_mat4_traits {
         impl Mul<$mat4> for $mat4 {
             type Output = Self;
             #[inline(always)]
-            fn mul(self, other: Self) -> Self {
+            fn mul(self, other: Self) -> Self::Output {
                 self.mul_mat4(&other)
             }
         }
@@ -628,7 +650,7 @@ macro_rules! impl_mat4_traits {
         impl Mul<$vec4> for $mat4 {
             type Output = $vec4;
             #[inline(always)]
-            fn mul(self, other: $vec4) -> $vec4 {
+            fn mul(self, other: $vec4) -> Self::Output {
                 self.mul_vec4(other)
             }
         }
@@ -636,7 +658,7 @@ macro_rules! impl_mat4_traits {
         impl Mul<$mat4> for $t {
             type Output = $mat4;
             #[inline(always)]
-            fn mul(self, other: $mat4) -> $mat4 {
+            fn mul(self, other: $mat4) -> Self::Output {
                 other.mul_scalar(self)
             }
         }
@@ -644,7 +666,7 @@ macro_rules! impl_mat4_traits {
         impl Mul<$t> for $mat4 {
             type Output = Self;
             #[inline(always)]
-            fn mul(self, other: $t) -> Self {
+            fn mul(self, other: $t) -> Self::Output {
                 self.mul_scalar(other)
             }
         }
@@ -717,8 +739,10 @@ type InnerF32 = Columns4<XYZW<f32>>;
 
 /// A 4x4 column major matrix.
 ///
-/// This 4x4 matrix type features convenience methods for creating and using affine
-/// transforms and perspective projections.
+/// This 4x4 matrix type features convenience methods for creating and using affine transforms and
+/// perspective projections. If you are primarily dealing with 3D affine transformations
+/// condidering using [`Affine3A`][crate::Affine3A] which is faster tha a 4x4 matrix for some
+/// affine operations.
 ///
 /// Affine transformations including 3D translation, rotation and scale can be created
 /// using methods such as [`Self::from_translation()`], [`Self::from_quat()`],
@@ -788,8 +812,10 @@ type InnerF64 = Columns4<XYZW<f64>>;
 
 /// A 4x4 column major matrix.
 ///
-/// This 4x4 matrix type features convenience methods for creating and using affine
-/// transforms and perspective projections.
+/// This 4x4 matrix type features convenience methods for creating and using affine transforms and
+/// perspective projections. If you are primarily dealing with 3D affine transformations
+/// condidering using [`DAffine3`][crate::DAffine3] which is faster tha a 4x4 matrix for some
+/// affine operations.
 ///
 /// Affine transformations including 3D translation, rotation and scale can be created
 /// using methods such as [`Self::from_translation()`], [`Self::from_quat()`],
