@@ -36,53 +36,79 @@ macro_rules! impl_quat_methods {
 
         /// Creates a new rotation quaternion.
         ///
-        /// This function does not check if the input is normalized, it is up to the user to
-        /// provide normalized input or to normalized the resulting quaternion.
-        ///
         /// This should generally not be called manually unless you know what you are doing.
         /// Use one of the other constructors instead such as `identity` or `from_axis_angle`.
         ///
         /// `from_xyzw` is mostly used by unit tests and `serde` deserialization.
+        ///
+        /// # Preconditions
+        ///
+        /// This function does not check if the input is normalized, it is up to the user to
+        /// provide normalized input or to normalized the resulting quaternion.
         #[inline(always)]
         pub fn from_xyzw(x: $t, y: $t, z: $t, w: $t) -> Self {
             Self(Vector4::new(x, y, z, w))
         }
 
-        /// Creates a new rotation quaternion from a 4D vector.
+        /// Creates a rotation quaternion from an array.
+        ///
+        /// # Preconditions
         ///
         /// This function does not check if the input is normalized, it is up to the user to
         /// provide normalized input or to normalized the resulting quaternion.
+        #[inline(always)]
+        pub fn from_array(a: [$t; 4]) -> Self {
+            let q = Vector4::from_array(a);
+            Self(q)
+        }
+
+        /// Creates a new rotation quaternion from a 4D vector.
         ///
-        /// The resulting quaternion is expected to be of unit length.
+        /// # Preconditions
+        ///
+        /// This function does not check if the input is normalized, it is up to the user to
+        /// provide normalized input or to normalized the resulting quaternion.
         #[inline(always)]
         pub fn from_vec4(v: $vec4) -> Self {
             Self(v.0)
         }
 
-        /// Creates a rotation quaternion from an unaligned slice.
+        #[deprecated(since = "0.15.2", note = "Please use `from_slice()` instead")]
+        #[inline(always)]
+        pub fn from_slice_unaligned(slice: &[$t]) -> Self {
+            Self::from_slice(slice)
+        }
+
+        /// Creates a rotation quaternion from a slice.
         ///
         /// # Preconditions
         ///
-        /// The resulting quaternion is expected to be of unit length.
+        /// This function does not check if the input is normalized, it is up to the user to
+        /// provide normalized input or to normalized the resulting quaternion.
         ///
         /// # Panics
         ///
         /// Panics if `slice` length is less than 4.
         #[inline(always)]
-        pub fn from_slice_unaligned(slice: &[$t]) -> Self {
+        pub fn from_slice(slice: &[$t]) -> Self {
             #[allow(clippy::let_and_return)]
             let q = Vector4::from_slice_unaligned(slice);
-            glam_assert!(FloatVector4::is_normalized(q));
             Self(q)
         }
 
+        #[deprecated(since = "0.15.2", note = "Please use `write_to_slice()` instead")]
+        #[inline(always)]
+        pub fn write_to_slice_unaligned(self, slice: &mut [$t]) {
+            self.write_to_slice(slice)
+        }
+
         /// Writes the quaternion to an unaligned slice.
         ///
         /// # Panics
         ///
         /// Panics if `slice` length is less than 4.
         #[inline(always)]
-        pub fn write_to_slice_unaligned(self, slice: &mut [$t]) {
+        pub fn write_to_slice(self, slice: &mut [$t]) {
             Vector4::write_to_slice_unaligned(self.0, slice)
         }
 
@@ -240,6 +266,7 @@ macro_rules! impl_quat_methods {
 
         /// Returns the quaternion conjugate of `self`. For a unit quaternion the
         /// conjugate is also the inverse.
+        #[must_use]
         #[inline(always)]
         pub fn conjugate(self) -> Self {
             Self(self.0.conjugate())
@@ -250,6 +277,7 @@ macro_rules! impl_quat_methods {
         /// Typically quaternion inverse returns the conjugate of a normalized quaternion.
         /// Because `self` is assumed to already be unit length this method *does not* normalize
         /// before returning the conjugate.
+        #[must_use]
         #[inline(always)]
         pub fn inverse(self) -> Self {
             glam_assert!(self.is_normalized());
@@ -291,6 +319,7 @@ macro_rules! impl_quat_methods {
         /// Returns `self` normalized to length 1.0.
         ///
         /// For valid results, `self` must _not_ be of length zero.
+        #[must_use]
         #[inline(always)]
         pub fn normalize(self) -> Self {
             Self(FloatVector4::normalize(self.0))
@@ -373,16 +402,16 @@ macro_rules! impl_quat_methods {
             Self(self.0.slerp(end.0, s))
         }
 
-        #[inline(always)]
         /// Multiplies a quaternion and a 3D vector, returning the rotated vector.
+        #[inline(always)]
         pub fn mul_vec3(self, other: $vec3) -> $vec3 {
             $vec3(self.0.mul_vector3(other.0))
         }
 
-        #[inline(always)]
         /// Multiplies two quaternions.
         /// If they each represent a rotation, the result will represent the combined rotation.
         /// Note that due to floating point rounding the result may not be perfectly normalized.
+        #[inline(always)]
         pub fn mul_quat(self, other: Self) -> Self {
             Self(self.0.mul_quaternion(other.0))
         }
@@ -421,12 +450,12 @@ macro_rules! impl_quat_traits {
 
         impl Add<$quat> for $quat {
             type Output = Self;
-            #[inline]
             /// Adds two quaternions.
             /// The sum is not guaranteed to be normalized.
             ///
             /// NB: Addition is not the same as combining the rotations represented by the two quaternions!
             /// That corresponds to multiplication.
+            #[inline]
             fn add(self, other: Self) -> Self {
                 Self(self.0.add(other.0))
             }
@@ -434,9 +463,9 @@ macro_rules! impl_quat_traits {
 
         impl Sub<$quat> for $quat {
             type Output = Self;
-            #[inline]
             /// Subtracts the other quaternion from self.
             /// The difference is not guaranteed to be normalized.
+            #[inline]
             fn sub(self, other: Self) -> Self {
                 Self(self.0.sub(other.0))
             }
@@ -444,9 +473,9 @@ macro_rules! impl_quat_traits {
 
         impl Mul<$t> for $quat {
             type Output = Self;
-            #[inline]
             /// Multiplies a quaternion by a scalar value.
             /// The product is not guaranteed to be normalized.
+            #[inline]
             fn mul(self, other: $t) -> Self {
                 Self(self.0.scale(other))
             }
@@ -454,9 +483,9 @@ macro_rules! impl_quat_traits {
 
         impl Div<$t> for $quat {
             type Output = Self;
-            #[inline]
             /// Divides a quaternion by a scalar value.
             /// The quotient is not guaranteed to be normalized.
+            #[inline]
             fn div(self, other: $t) -> Self {
                 Self(self.0.scale(other.recip()))
             }
@@ -605,8 +634,8 @@ pub struct Quat(pub(crate) InnerF32);
 impl Quat {
     impl_quat_methods!(f32, Quat, Vec3, Vec4, Mat3, Mat4, InnerF32);
 
-    #[inline(always)]
     /// Multiplies a quaternion and a 3D vector, returning the rotated vector.
+    #[inline(always)]
     pub fn mul_vec3a(self, other: Vec3A) -> Vec3A {
         #[allow(clippy::useless_conversion)]
         Vec3A(self.0.mul_float4_as_vector3(other.0.into()).into())
