@@ -372,8 +372,8 @@ macro_rules! impl_vec2_tests {
         fn test_to_from_slice() {
             let v = $vec2::new(1 as $t, 2 as $t);
             let mut a = [0 as $t, 0 as $t];
-            v.write_to_slice_unaligned(&mut a);
-            assert_eq!(v, $vec2::from_slice_unaligned(&a));
+            v.write_to_slice(&mut a);
+            assert_eq!(v, $vec2::from_slice(&a));
         }
 
         #[cfg(feature = "std")]
@@ -557,6 +557,16 @@ macro_rules! impl_vec2_float_tests {
             );
         }
 
+        #[test]
+        fn test_fract() {
+            assert_approx_eq!($vec2::new(1.35, -1.5).fract(), $vec2::new(0.35, 0.5));
+            assert_approx_eq!(
+                $vec2::new(-2000000.123, 1000000.123).fract(),
+                $vec2::new(0.877, 0.123),
+                0.002
+            );
+        }
+
         #[test]
         fn test_ceil() {
             assert_eq!($vec2::new(1.35, -1.5).ceil(), $vec2::new(2.0, -1.0));
