@@ -416,8 +416,8 @@ macro_rules! impl_vec3_tests {
         fn test_to_from_slice() {
             let v = $vec3::new(1 as $t, 2 as $t, 3 as $t);
             let mut a = [0 as $t, 0 as $t, 0 as $t];
-            v.write_to_slice_unaligned(&mut a);
-            assert_eq!(v, $vec3::from_slice_unaligned(&a));
+            v.write_to_slice(&mut a);
+            assert_eq!(v, $vec3::from_slice(&a));
         }
 
         #[cfg(feature = "std")]
@@ -602,6 +602,18 @@ macro_rules! impl_vec3_float_tests {
             );
         }
 
+        #[test]
+        fn test_fract() {
+            assert_approx_eq!(
+                $vec3::new(1.35, 1.5, -1.5).fract(),
+                $vec3::new(0.35, 0.5, 0.5)
+            );
+            assert_approx_eq!(
+                $vec3::new(-200000.123, 1000000.123, 1000.9).fract(),
+                $vec3::new(0.877, 0.123, 0.9),
+                0.002
+            );
+        }
         #[test]
         fn test_ceil() {
             assert_eq!(
